pub struct BulkInsertBuilder<'e, V: ValidationMode = Validated> { /* private fields */ }Expand description
Main builder for bulk insert operations.
Type parameter V tracks the validation mode at compile time.
Implementations
Sourceimpl<'e, V: ValidationMode> BulkInsertBuilder<'e, V>
impl<'e, V: ValidationMode> BulkInsertBuilder<'e, V>
Sourcepub fn table<'a>(
&'a mut self,
qualified_name: &str,
) -> TableInsertBuilder<'a, 'e, V>
pub fn table<'a>( &'a mut self, qualified_name: &str, ) -> TableInsertBuilder<'a, 'e, V>
Begin inserting into a table.
The qualified name can be either “namespace::table” or just “table” (which uses the default namespace).
Sourcepub fn ringbuffer<'a>(
&'a mut self,
qualified_name: &str,
) -> RingBufferInsertBuilder<'a, 'e, V>
pub fn ringbuffer<'a>( &'a mut self, qualified_name: &str, ) -> RingBufferInsertBuilder<'a, 'e, V>
Begin inserting into a ring buffer.
The qualified name can be either “namespace::ringbuffer” or just “ringbuffer” (which uses the default namespace).
Sourcepub fn execute(self) -> Result<BulkInsertResult>
pub fn execute(self) -> Result<BulkInsertResult>
Execute all pending inserts in a single transaction.
Returns a summary of what was inserted. On error, the entire transaction is rolled back (no partial inserts).