RingBufferInsertBuilder

Struct RingBufferInsertBuilder 

pub struct RingBufferInsertBuilder<'a, 'e, V: ValidationMode> { /* private fields */ }
Builder for inserting rows into a specific ring buffer.

Created by calling ringbuffer() on a BulkInsertBuilder. Call done() to finish and return to the main builder.

Implementations

Source

impl<'a, 'e, V: ValidationMode> RingBufferInsertBuilder<'a, 'e, V>

pub fn row(self, params: Params) -> Self

Add a single row from named params.

Example
builder.row(params!{ timestamp: 12345, event_type: "login" })
pub fn rows<I>(self, iter: I) -> Self
where I: IntoIterator<Item = Params>,

Add multiple rows from an iterator.

Example
let rows = vec![
    params!{ timestamp: 12345, event_type: "login" },
    params!{ timestamp: 12346, event_type: "logout" },
];
builder.rows(rows)
pub fn done(self) -> &'a mut BulkInsertBuilder<'e, V>

Finish this ring buffer insert and return to the main builder.

This allows chaining to insert into additional targets.