Module validation

Module validation 

Functions

reorder_rows_unvalidated
Reorder all rows for a table without coercion.
reorder_rows_unvalidated_rb
Reorder all rows for a ring buffer without coercion. Companion to reorder_rows_unvalidated for ring buffers.
reorder_rows_unvalidated_series
Reorder all rows for a series without coercion. Companion to reorder_rows_unvalidated for series.
validate_and_coerce_rows
Validate and coerce all rows for a table in columnar batch mode.
validate_and_coerce_rows_rb
Validate and coerce all rows for a ring buffer in columnar batch mode.
validate_and_coerce_rows_series
Validate and coerce all rows for a series in columnar batch mode.