reorder_rows_unvalidated

Function reorder_rows_unvalidated 

pub fn reorder_rows_unvalidated(
    rows: &[Params],
    table: &Table,
) -> Result<Vec<Vec<Value>>>
Reorder all rows for a table without coercion.

Used by Unchecked mode when validation is skipped for pre-validated internal data. The caller is responsible for ensuring the rows already conform to the table’s column types.