Module compiler

Module compiler 

Modules

operator
primitive

Functions

compile_flow
Public API for compiling logical plans to Flows with an existing flow ID.
compile_subscription_flow_ephemeral
Compile a subscription flow without persisting to the catalog.