pub fn load_procedures_from_dir(dir: &Path) -> Result<Procedures>Expand description
Scan a directory for FFI procedure shared libraries, register them,
and return a Procedures registry with factory functions for each.
pub fn load_procedures_from_dir(dir: &Path) -> Result<Procedures>Scan a directory for FFI procedure shared libraries, register them,
and return a Procedures registry with factory functions for each.