Module session

Module session 

Structs

RetryStrategy
Controls how many times a write transaction is retried on conflict (TXN_001).
Session
A unified session binding an identity to a database engine.

Enums

Backoff
Backoff strategy between retry attempts.