pub struct Services {
pub catalog: Catalog,
pub clock: Clock,
pub compiler: Compiler,
pub functions: Functions,
pub procedures: Procedures,
pub transforms: Transforms,
pub flow_operator_store: FlowOperatorStore,
pub virtual_table_registry: UserVTableRegistry,
pub stats_reader: MetricReader<SingleStore>,
pub ioc: IocContainer,
pub auth_registry: AuthenticationRegistry,
}Expand description
Services is a container for shared resources used throughout the execution engine.
This struct provides a single location for all the shared resources that the VM, query operators, and other components need access to.
Fields
catalog: Catalogclock: Clockcompiler: Compilerfunctions: Functionsprocedures: Procedurestransforms: Transformsflow_operator_store: FlowOperatorStorevirtual_table_registry: UserVTableRegistrystats_reader: MetricReader<SingleStore>ioc: IocContainerauth_registry: AuthenticationRegistryImplementations
Sourceimpl Services
impl Services
pub fn new( catalog: Catalog, clock: Clock, functions: Functions, procedures: Procedures, transforms: Transforms, flow_operator_store: FlowOperatorStore, stats_reader: MetricReader<SingleStore>, ioc: IocContainer, ) -> Self
pub fn get_handlers( &self, sumtype_id: SumTypeId, variant_tag: u8, ) -> Vec<Box<dyn Procedure>>
pub fn get_procedure(&self, name: &str) -> Option<Box<dyn Procedure>>
pub fn testing() -> Arc<Self>