Module stack

Module stack 

Structs

Stack
The VM data stack for intermediate results
SymbolTable
Context for storing and managing variables during query execution with scope support

Enums

ControlFlow
Control flow signal for loop and function constructs
Variable
A variable can be either a scalar value, columnar data, or a FOR loop iterator