Fluent API for fast bulk inserts into sources.
This module provides a builder pattern API that bypasses RQL parsing for maximum insert performance. All inserts within a single builder execute in one transaction (one request = one transaction).
Example
ⓘ
use reifydb_type::params;
engine.bulk_insert(&identity)
.table("namespace::users")
.row(params!{ id: 1, name: "Alice" })
.row(params!{ id: 2, name: "Bob" })
.done()
.ringbuffer("namespace::events")
.row(params!{ timestamp: 12345, event_type: "login" })
.done()
.execute()?;Modules
- builder
- coerce
- Column coercion for bulk inserts.
- primitive
- validation
- Row validation and column mapping for bulk inserts with batch coercion.
Structs
- Bulk
Insert Result - Result of a bulk insert operation
- Ring
Buffer Insert Result - Result of inserting into a specific ring buffer
- Table
Insert Result - Result of inserting into a specific table