Module validation

Module validation 

Row validation and column mapping for bulk inserts with batch coercion.

Functions

reorder_rows_trusted
Reorder all rows for a table without coercion (trusted mode).
reorder_rows_trusted_rb
Reorder all rows for a ring buffer without coercion (trusted mode).
validate_and_coerce_rows
Validate and coerce all rows for a table in columnar batch mode.
validate_and_coerce_rows_rb
Validate and coerce all rows for a ring buffer in columnar batch mode.