Row validation and column mapping for bulk inserts with batch coercion.
Functions
- reorder_
rows_ trusted - Reorder all rows for a table without coercion (trusted mode).
- reorder_
rows_ trusted_ rb - Reorder all rows for a ring buffer without coercion (trusted mode).
- validate_
and_ coerce_ rows - Validate and coerce all rows for a table in columnar batch mode.
- validate_
and_ coerce_ rows_ rb - Validate and coerce all rows for a ring buffer in columnar batch mode.