pub fn validate_and_coerce_rows(
rows: &[Params],
table: &Table,
) -> Result<Vec<Vec<Value>>>Expand description
Validate and coerce all rows for a table in columnar batch mode.
Processes all rows at once by:
- Collecting params into columnar format
- Coercing each column’s data in one batch using
cast_column_data - Extracting coerced values back to row format
Returns Vec<Vec<Value>> where outer vec is rows, inner is column values in table column order.