Flow compilation module - compiles RQL plans into Flows
This module contains the flow compiler that was moved from reifydb-rql to avoid lifetime issues with async recursion and generic MultiVersionCommandTransaction types.
Modules
- compiler
- Flow compilation - compiles RQL physical plans into Flows